// Generated by dts-bundle-generator v9.5.1

import { AxiosPromise } from 'axios';
import { EventEmitter } from 'events';
import { GeoJsonProperties, LineString, Point } from 'geojson';
import maplibregl$1 from 'maplibre-gl';
import { ControlPosition, ExpressionSpecification, FilterSpecification, IControl, LngLat, MapGeoJSONFeature, MapLayerEventType, PaddingOptions, PointLike, RequireAtLeastOne } from 'maplibre-gl';

/** @deprecated */
export declare enum FloorSwitchMode {
	SWITCHED_BY_BUILDING = 0,
	SWITCHED_BY_VENUE = 1
}
export declare enum PresetLanguage {
	ENGLISH = "en",
	CHINESE_SIMPLIFIED = "zh-Hans",
	CHINESE_TRADITIONAL = "zh-Hant",
	JAPANESE = "ja",
	KOREAN = "ko",
	FILIPINO = "fil",
	INDONESIAN = "id",
	PORTUGUESE = "pt",
	THAI = "th",
	VIETNAMESE = "vi",
	ARABIC = "ar"
}
export declare enum ThemeType {
	CHRISTMAS = "christmas",
	HALLOWEEN = "halloween",
	MAPPY_BEE = "mappyBee",
	MAPXUS = "mapxus",
	LANDS_D = "landsD",
	COMMON = "common",
	/** @deprecated MAPXUS_V2 will be removed soon, please use MAPXUS_DEFAULT instead. */
	MAPXUS_V2 = "mapxus_v2",
	MAPXUS_DEFAULT = "mapxus_default"
}
export declare enum AccessControlOrigin {
	Self = "self",
	Map = "map"
}
export interface IBbox {
	maxLat: number;
	maxLon: number;
	minLat: number;
	minLon: number;
}
export interface IBuildingChangedOptions {
	buildingId: string | null;
	ordinal: string | null;
	dragPan: boolean | "restrict";
}
export interface IMultilingualName extends Partial<Record<PresetLanguage, string>> {
	default: string;
}
export type IMultilingualAddress = Record<keyof IMultilingualName, {
	housenumber: string;
	street: string;
}>;
export interface ILocation {
	lat: number;
	lon: number;
}
export interface IResponse<T> {
	code: number;
	message: string;
	result: T;
}
export interface IBuildingInlineFloor {
	code: string;
	id: string;
	ordinal: number;
	signalMap: boolean;
	visualMap: boolean;
}
export interface IBuilding {
	address: IMultilingualAddress;
	bbox: IBbox;
	buildingId: string;
	buildingOutlineId: number;
	city?: string;
	country: string;
	defaultFloor?: string;
	floors: IBuildingInlineFloor[];
	groundFloor: string;
	isPrivate: "yes" | "no";
	labelCenter: ILocation;
	name: IMultilingualName;
	organization: string;
	region: string;
	signalMap: boolean;
	type: string;
	venueId: string;
	venueName: IMultilingualName;
	visualMap: boolean;
}
export interface IResponseBuildings {
	buildings: IBuilding[];
	total: number;
}
export type TPromiseBuildings = AxiosPromise<IResponse<IResponseBuildings>>;
export interface IBuildingSearchCustomizedOptions {
	bounds?: [
		[
			number,
			number
		],
		[
			number,
			number
		]
	];
	center?: [
		number,
		number
	];
	distance?: number;
	keywords?: string;
	signal?: boolean;
	visual?: boolean;
	offset?: number;
	page?: number;
}
export type TPointFeature = GeoJSON.Feature<Point, GeoJsonProperties>;
export type TLineStringFeature = GeoJSON.Feature<LineString, GeoJsonProperties>;
export interface IFloor {
	code: string | null;
	id: string | null;
	ordinal: string | null;
}
export interface IFloorSelectorStyle {
	fontColor?: string;
	activeFontColor?: string;
	backgroundColor?: string;
	activeBackgroundColor?: string;
	itemSize?: number;
	itemCount?: number;
	defaultFolded?: boolean;
}
export interface IMapClickEvent {
	coordinate: LngLat;
	building: MapGeoJSONFeature | null;
	venue: MapGeoJSONFeature | null;
	floor: IFloor;
}
export interface ISelectedBuildingBorderStyle {
	lineWidth?: number;
	lineColor?: string;
	lineOpacity?: number;
}
export interface IMapOption {
	map: maplibregl$1.Map;
	appId: string;
	secret: string;
	floorSelectorEnabled?: boolean;
	buildingSelectorEnabled?: boolean;
	/**
	 * @description 'venueId', 'buildingId', 'floorId', 'poiId' are mutually exclusive,
	 * the priority is: poiId > floorId > buildingId > venueId.
	 */
	venueId?: string;
	/**
	 * @description 'venueId', 'buildingId', 'floorId', 'poiId' are mutually exclusive,
	 * the priority is: poiId > floorId > buildingId > venueId.
	 */
	buildingId?: string;
	/**
	 * @description 'venueId', 'buildingId', 'floorId', 'poiId' are mutually exclusive,
	 * the priority is: poiId > floorId > buildingId > venueId.
	 */
	floorId?: string;
	/**
	 * @description Initialize the map with POI as the center point, use it with maplibregl.Map 'zoom' option.
	 * 'venueId', 'buildingId', 'floorId', 'poiId' are mutually exclusive,
	 * the priority is: poiId > floorId > buildingId > venueId.
	 */
	poiId?: string;
	outdoorMapShown?: boolean;
	theme?: ThemeType | string;
	/** @deprecated 'collapseCopyright' will be removed soon. You'd not use it. */
	collapseCopyright?: boolean;
	selectedBuildingBorderStyle?: ISelectedBuildingBorderStyle;
	floorSelectorStyle?: IFloorSelectorStyle;
	/**
	 * @description Switch floors by venue/building, default by venue.
	 * @deprecated 'floorSwitchMode' will be removed soon.
	 */
	floorSwitchMode?: FloorSwitchMode;
	/**
	 * @description Whether unselected buildings are masked, default is false.
	 */
	maskNonSelectedAreas?: boolean;
	/**
	 * @description Whether the boundary of the selected building fits the screen, default is false.
	 * Can only be used for 'floorId', 'buildingId' and 'venueId' initialization, not for 'poiId'.
	 * When it is true, the 'boundsPadding' option is valid, and the 'zoom' option of maplibregl.Map is invalid.
	 */
	fitBuildingBounds?: boolean;
	/**
	 * @description The amount of padding in pixels to add to the given bounds, default is 30.
	 * Requires 'fitBuildingBounds' to be 'true'.
	 * Parameter value ref to: https://maplibre.org/maplibre-gl-js/docs/API/types/maplibregl.PaddingOptions/
	 */
	boundsPadding?: number | RequireAtLeastOne<PaddingOptions>;
	language?: PresetLanguage;
	/** @description Auto Select Building by panning building to map center, default is false. */
	autoSelectBuilding?: boolean;
	transformRequest?: maplibregl$1.RequestTransformFunction | null;
	mapxusLogoEnabled?: boolean;
}
export type TAnchorPosition = "center" | "left" | "right" | "top" | "bottom" | "top-left" | "top-right" | "bottom-left" | "bottom-right";
export interface IMarkerOptions {
	lngLat: [
		number,
		number
	];
	properties?: {
		[k: string]: string;
	};
}
export interface IMarkerOptionsWithFeatureId extends IMarkerOptions {
	featureId: number;
}
export interface IPoiEvent {
	coordinate: LngLat;
	poi: MapGeoJSONFeature;
	building: MapGeoJSONFeature | null;
	venue: MapGeoJSONFeature | null;
	floor: IFloor;
}
export interface IPointEvent {
	coordinate: LngLat;
	point: PointLike;
}
export declare enum DistanceSearchType {
	POINT = "Point",
	POLYGON = "Polygon"
}
export declare enum OrientationDistanceSearchType {
	POINT = "Point",
	POLYGON = "Polygon",
	GATE = "Gate"
}
export interface IBoundsSpec {
	/** An array of LngLat coordinates in [sw, ne] order */
	bounds: [
		[
			number,
			number
		],
		[
			number,
			number
		]
	];
}
export interface IKeywordSpec {
	keywords?: string;
}
export interface IBuildingSpec {
	buildingId: string;
}
export interface IVenueSpec {
	venueId: string;
}
export interface IFloorSpec {
	floorId: string;
}
export type TSearchCategoriesOptions = IVenueSpec | IBuildingSpec | IFloorSpec | (IBoundsSpec & IKeywordSpec);
export interface IPoi {
	accessibilityDetail: IMultilingualName;
	buildingId: string;
	category: string[];
	distance: number;
	floor: string;
	floorId: string;
	id: string;
	location: ILocation;
	name: IMultilingualName;
	osmRefId: number;
	poiId: string;
	venueId: string;
	descriptions?: IMultilingualName;
	email?: string;
	openingHours?: string;
	phone?: string;
	website?: string;
}
export interface IResponsePois {
	pois: IPoi[];
	total: number;
}
export type TPromisePois = AxiosPromise<IResponse<IResponsePois>>;
export type TPromiseCategories = AxiosPromise<IResponse<IPoiCategory[]>>;
export type TPromiseOrientationPois = AxiosPromise<IResponse<IOrientationPoi[]>>;
export interface IPoiCategory {
	category: string;
	description: string | null;
	id: string;
	title: Partial<Record<keyof IMultilingualName, string>>;
}
export interface IOrientationPoi {
	angle: number;
	buildingId: string;
	category: string[];
	distance: number;
	distanceSource: string;
	floor: string;
	floorId: string;
	id: string;
	location: ILocation;
	name: IMultilingualName;
	osmRefId: number;
	poiId: string;
	description?: string;
	email?: string;
	openingHours?: string;
	phone?: string;
	website?: string;
}
export interface ISearchDistance {
	/**
	 * The center of searching range, [lng, lat].
	 */
	center: [
		number,
		number
	];
	/**
	 * Radius from center, unit is meter, cannot exceed 10,000.
	 */
	distance: number;
	/**
	 * The maximum value is 100, default is 10.
	 */
	offset?: number;
	/**
	 * Results for specified page number. Default is 1.
	 */
	page?: number;
}
export interface IPoiSearchByCategoryOptions extends ISearchDistance {
	category: string;
}
export interface IPoiSearchByExcludedCategoriesOptions extends ISearchDistance {
	excludedCategories: string | string[];
}
export type TPoiSearchByCategoryOptions = IPoiSearchByCategoryOptions | IPoiSearchByExcludedCategoriesOptions;
export interface IPoiSearchByDistanceOptions extends ISearchDistance {
	/**
	 * Keywords of POI name.
	 */
	keywords?: string;
}
export interface ISearchOrientation {
	/**
	 * User's position, [lng, lat].
	 */
	center: [
		number,
		number
	];
	/**
	 * The angle between the user's orientation and true north.
	 */
	angle: number;
	/**
	 * The radius with 'center' as the center of the circle.
	 */
	distance: number;
	/**
	 * The type of POI, default is 'Point'.
	 */
	distanceSearchType?: OrientationDistanceSearchType;
}
export interface IPoiSearchByOrientationAndBuildingOptions extends ISearchOrientation {
	buildingId: string;
}
export interface IPoiSearchByOrientationAndFloorOptions extends ISearchOrientation {
	floorId: string;
}
export interface IPoiSearchByOrientationAndOrdinalOptions extends ISearchOrientation {
	ordinal: string;
}
export type TPoiSearchByOrientationOptions = IPoiSearchByOrientationAndBuildingOptions | IPoiSearchByOrientationAndFloorOptions | IPoiSearchByOrientationAndOrdinalOptions;
export declare enum PoisOrderBy {
	DEFAULT_NAME = "DefaultName"
}
export declare enum PoisSortBy {
	ABSOLUTE_DISTANCE = "AbsoluteDistance",
	ACTUAL_DISTANCE = "ActualDistance"
}
export interface ISearchKeywords {
	keywords?: string;
	/**
	 * Quantity per page, the maximum is 100, default is 10.
	 */
	offset?: number;
	/**
	 * Results for specified page number. Default is 1.
	 */
	page?: number;
}
export interface IPoiSearchByBuildingOptions extends ISearchKeywords {
	buildingId: string;
	orderBy?: PoisOrderBy;
}
export interface IPoiSearchByVenueOptions extends ISearchKeywords {
	venueId: string;
	orderBy?: PoisOrderBy;
}
export interface IPoiSearchByFloorOptions extends ISearchKeywords {
	floorId: string;
	orderBy?: PoisOrderBy;
}
export interface IPoiSearchByBoundsOptions extends ISearchKeywords {
	/**
	 * An array of LngLat coordinates in [sw, ne] order
	 */
	bounds: [
		[
			number,
			number
		],
		[
			number,
			number
		]
	];
	orderBy?: PoisOrderBy;
}
export interface IPoiSearchCustomizedOptions {
	bounds?: [
		[
			number,
			number
		],
		[
			number,
			number
		]
	];
	center?: [
		number,
		number
	];
	distance?: number;
	category?: string;
	excludedCategories?: string | string[];
	floorId?: string;
	buildingId?: string;
	venueId?: string;
	keywords?: string;
	orderBy?: PoisOrderBy;
	sort?: PoisSortBy;
	distanceSearchType?: DistanceSearchType;
	offset?: number;
	page?: number;
}
export interface ITokenInfo {
	"app:name": string;
	auth_time: number;
	"cognito:username": string;
	"custom:organization": string;
	exp: number;
	iat: number;
	organization: string;
	"organization:name": string;
	privatization_type: string;
	username: string;
}
export declare enum VehicleType {
	FOOT = "foot",
	WHEELCHAIR = "wheelchair",
	ESCALATOR = "escalator",
	EMERGENCY = "emergency"
}
export interface IRouteInfo {
	copyrights: string[];
	took: number;
}
export interface IInstruction {
	building_id: string;
	distance: number;
	floor_id: string;
	heading: number;
	interval: [
		number,
		number
	];
	ordinal: number;
	sign: number;
	street_name: string;
	text: string;
	time: number;
	type: string | null;
	venue_id: string;
}
export interface IRoutePath {
	bbox: [
		number,
		number,
		number,
		number
	];
	distance: number;
	instructions: IInstruction[];
	points: {
		coordinates: Array<[
			number,
			number
		]>;
		type: string;
	};
	snapped_waypoints: {
		coordinates: Array<[
			number,
			number
		]>;
		type: string;
	};
	time: number;
}
export interface IResponseRoute {
	infos: IRouteInfo | null;
	paths: IRoutePath[];
}
export type TPromiseRoute = AxiosPromise<IResponse<IResponseRoute>>;
export interface IRouteSearchOptions {
	/**
	 * @description Points are in order, from -> stops -> to.
	 * The length of points must be: 1 < {points.length} < 6.
	 */
	points: Array<{
		lat: number;
		lon: number;
		floorId?: string;
	}>;
	/**
	 * @description Default is "foot".
	 */
	vehicle?: VehicleType;
	/**
	 * @description Language-specific response. Default is "en".
	 */
	locale?: PresetLanguage;
}
export interface IVenueInlineBuilding {
	buildingOutlineId: number;
	defaultFloor?: string;
	floors: IBuildingInlineFloor[];
	id: string;
	labelCenter: ILocation;
	name: IMultilingualName;
	point: {
		type: string;
		coordinates: [
			number,
			number
		];
	};
	signalMap: boolean;
	visualMap: boolean;
}
export interface IVenue {
	address: IMultilingualAddress;
	bbox: IBbox;
	buildings: IVenueInlineBuilding[];
	businessStatus?: {
		status: string;
	};
	country: string;
	defaultBuilding?: string;
	id: string;
	labelCenter: ILocation;
	name: IMultilingualName;
	organization: string[];
	owner: string;
	publicData?: string[];
	photos?: object[];
	region: string;
	restricted: boolean;
	signalMap: boolean;
	totalPhotoCount?: number;
	type: string;
	venueOutlineId: number;
	visualMap: boolean;
}
export interface IResponseVenues {
	venues: IVenue[];
	total: number;
}
export type TPromiseVenues = AxiosPromise<IResponse<IResponseVenues>>;
export interface IVenueSearchCustomizedOptions extends IBuildingSearchCustomizedOptions {
}
export declare class Indoor extends EventEmitter {
	private _map;
	private _features;
	private _allBuildings;
	private _curBuildingId;
	private _curBuildingFeature;
	private _ordinal;
	private _floorId;
	private _floorName;
	private _allowOutdoorSwitch;
	private _allowBuildingSwitch;
	private _outdoorMapShown;
	private _originIndoorLayers;
	private _curVenueId;
	private _curVenueFeature;
	private _buildingHighlightStyle;
	private _lowerLayers;
	private _upperLayers;
	private _commonLayers;
	private _dispatch;
	private readonly _fitBuildingBounds;
	private readonly _boundsPadding;
	private readonly _startWithIndoorView;
	private _maplibreMapLoaded;
	private _indoorMapLoaded;
	private readonly _isVenueMode;
	private readonly _isMaskMode;
	private _upperLevels;
	private _lowerLevels;
	private _featureIncomplete;
	private _dragPan;
	private _isNewBuilding;
	private _buildingBounds;
	private _history;
	private _layerBuildings;
	private _upperBuildings;
	private _lowerBuildings;
	private readonly _hiddenBuildings;
	private _isDestroyed;
	private _findBuildingTimeoutId;
	private _findBuildingIntervalId;
	private _debounceRendering;
	constructor(props: {
		map: maplibregl$1.Map;
		/** @deprecated */
		floorSwitchMode?: FloorSwitchMode;
		fitBuildingBounds?: boolean;
		boundsPadding?: number | RequireAtLeastOne<PaddingOptions>;
		maskNonSelectedAreas?: boolean;
		startWithIndoorView?: boolean;
		outdoorMapShown?: boolean;
		selectedBuildingBorderStyle?: ISelectedBuildingBorderStyle;
	});
	destroy(): void;
	/**
	 * @description Set whether to allow exiting building.
	 * @param allow
	 */
	setAllowOutdoorSwitch(allow: boolean): this;
	/**
	 * @description Set whether to allow switching building.
	 * @param allow
	 */
	setAllowBuildingSwitch(allow: boolean): this;
	/**
	 * @description Get the current floor's information.
	 */
	get floor(): IFloor;
	/**
	 * @description Get the current building's information.
	 * @returns {MapGeoJSONFeature | null}
	 */
	get building(): MapGeoJSONFeature | null;
	/**
	 * @description Get the current venue's information.
	 * @returns {MapGeoJSONFeature | null}
	 */
	get venue(): MapGeoJSONFeature | null;
	/**
	 * @description Get the geo features of bbox.
	 */
	get features(): MapGeoJSONFeature[];
	/**
	 * @description Get features from bbox by id.
	 * @param id
	 * @param options
	 */
	getFeaturesById(id: string, options?: {
		layerIds?: string[];
		filter?: (feature: MapGeoJSONFeature) => boolean;
	}): MapGeoJSONFeature[];
	/**
	 * @description Switch floor by ordinal.
	 * @param ordinal
	 */
	switchFloorByOrdinal(ordinal: string | null): Promise<void>;
	setOutdoorMapShown(shown: boolean): void;
	/**
	 * @description Update map layout.
	 */
	updateCustomLayers(): void;
	/**
	 * @description Set the style of SelectedBuildingBorder. If set to null, the border will be invisible.
	 * @param style {ISelectedBuildingBorderStyle | null}
	 */
	setSelectedBuildingBorderStyle(style: ISelectedBuildingBorderStyle | null): void;
	/**
	 * @description Listen for the indoor map state, including the changes of venue, building and floor.
	 * @param listener
	 */
	onMapChange(listener: (params: {
		venue: MapGeoJSONFeature | null;
		building: MapGeoJSONFeature | null;
		floor: IFloor;
	}) => void): {
		unsubscribe: VoidFunction;
	};
	/**
	 * @description Select a building feature
	 * @param feature {MapGeoJSONFeature | null}
	 * @param options {floorId?: string, dragPan?: boolean}
	 */
	selectBuilding(feature: MapGeoJSONFeature | null, options?: {
		floorId?: string;
		featureIncomplete?: boolean;
	}): Promise<void>;
	updateRendering(): void;
	panToBuildingCenter(): Promise<unknown>;
	fitBuildingBbox(): void;
	setDragPan(dragPan: boolean | "restrict"): void;
	setBuildingBounds(bounds: [
		[
			number,
			number
		],
		[
			number,
			number
		]
	]): void;
	selectBuildingByClickMap(point: PointLike): Promise<void>;
	private _loadData;
	private _init;
	private _clear;
	private _getIndoorFeatures;
	private _getBuildingFloorByOrdinal;
	private _isNotCurrentFeature;
	private _setOutdoorVisibility;
	private _addCustomLevelFillLayer;
	private _setBuildingLineOpacity;
	private _addBuildingHighlightLayer;
	private _filterBuildingHighlight;
	private _handleBuildings;
	private _getVenueDefaultOrdinal;
	private _getBuildingDefaultOrdinal;
	private _getBuildingsOfBbox;
	private _copyOverlapLayers;
	private _updateFeatures;
	private _layerDisplayedBuildings;
	private _setDisplayedLevels;
	private _filterTiles;
	private _filterIndoorLayers;
	private _updateIndoorState;
	private _updateFloorState;
	private _resetSelectedBuildingLevel;
	private _checkAndPanToBuilding;
	private _invisibleSelectedBuilding;
	private _clearTimers;
}
export declare class BuildingFilterControl implements IControl {
	private _map;
	private _maplibre;
	private _buildingId;
	private _features;
	private _$container;
	private _$listContainer;
	private _$buildingList;
	private _listHeight;
	private _visible;
	private _position;
	constructor(map: Map$1, buildingSelectorEnabled?: boolean);
	onAdd(map: maplibregl$1.Map): HTMLElement;
	onRemove(): void;
	get position(): ControlPosition;
	get enabled(): boolean;
	getDefaultPosition(): ControlPosition;
	setVisibility(isVisible: boolean): void;
	changePosition(from: ControlPosition, to: ControlPosition, index?: number): void;
	private _loadData;
	private _init;
	private _refresh;
	private _load;
	private _buildingFilterIconCreate;
	private _buildingNameListCreate;
	private _buildingNameListUpdate;
	private _buildingNameListClean;
	private _setBuildingListHeight;
	private _buildingNameCreate;
	private _toggleList;
	private _buildingNameClickEvent;
	private _buildingToggleListEvent;
	private _$showLayout;
	private _$hideLayout;
	private _updateBuildingListLayout;
}
export interface IFloorSelectorOptions {
	style?: IFloorSelectorStyle;
	enabled?: boolean;
}
export declare class FloorsControl implements IControl {
	private _container;
	private _indoor;
	private _maplibre;
	private _position;
	private _buildingId;
	private _floorNames;
	private _ordinals;
	private _ordinal;
	private _style;
	private _$innerFloors;
	private _$activeFloor;
	private _centerSelectorIdx;
	private _lastNormalScrollableIdx;
	private _$arrowBtnUp;
	private _$arrowBtnDown;
	private _maxScrollTop;
	private _$selectorExpanded;
	private _$selectorFolded;
	private _componentDidMount;
	private _isEnabled;
	private _visible;
	private _dragPan;
	private _debounceScroll;
	private _clearScrollEventListener;
	constructor(indoor: Indoor, options: IFloorSelectorOptions);
	onAdd(map: maplibregl$1.Map): HTMLElement;
	onRemove(): void;
	get position(): ControlPosition;
	get enabled(): boolean;
	setEnabled(enabled: boolean): void;
	getDefaultPosition(): ControlPosition;
	/**
	 * @description Switch floor by ordinal
	 * @param ordinal
	 * @param dragPan
	 */
	switchByOrdinal(ordinal: string, dragPan?: boolean): Promise<void>;
	changePosition(from: ControlPosition, to: ControlPosition, index?: number): void;
	setStyle(style: Partial<IFloorSelectorStyle>): void;
	private _setVisibility;
	private _bindEvents;
	private _addMapMoveEventListener;
	private _mountFloors;
	private _updateFloorSelector;
	private _clearState;
	private _render;
	private _hide;
	private _show;
	private _createFloors;
	private _$expandedSelector;
	private _$foldedSelector;
	private _clearFloors;
	private _$createScrollButton;
	private _$createFloors;
	private _updateSelectorStatus;
	private _resetArrowBtnStatus;
	private _resetActiveFloor;
	private _scrollCenterActiveFloor;
	private _getScrollTop;
	private _handleScroll;
	private _expandSelector;
}
export declare class BuildingSelectorHandler {
	private _buildingSelector;
	private _isEnabled;
	private _position;
	constructor(buildingSelector: BuildingFilterControl);
	enable(): void;
	disable(): void;
	/**
	 * Set the position of the building selector control
	 * @param position
	 * @param index - The index of the control in the controls-container. Default at the last.
	 */
	setPosition(position: ControlPosition, index?: number): void;
	get isEnabled(): boolean;
	get position(): ControlPosition;
}
export declare class FloorSelectorHandler {
	private _floorSelector;
	private _isEnabled;
	private _position;
	constructor(floorSelector: FloorsControl);
	enable(): void;
	disable(): void;
	/**
	 * Set the position of the floor selector control
	 * @param position
	 * @param index - The index of the control in the controls-container. Default at the last.
	 */
	setPosition(position: ControlPosition, index?: number): void;
	setStyle(style: IFloorSelectorStyle): void;
	get isEnabled(): boolean;
	get position(): ControlPosition;
}
export declare class SwitchBuildingHandler {
	private _indoor;
	private _isEnabled;
	constructor(indoor: Indoor);
	enable(): void;
	disable(): void;
	get isEnabled(): boolean;
}
export declare class SwitchOutdoorHandler {
	private _indoor;
	private _isEnabled;
	constructor(indoor: Indoor);
	enable(): void;
	disable(): void;
	get isEnabled(): boolean;
}
declare class Map$1 {
	private _appId;
	private _map;
	private _indoor;
	private _poi;
	private _floorsControl;
	private _buildingFilterControl;
	private _attributionControl;
	private _initialHiddenLayers;
	private _language;
	private _dispatch;
	private _fitBuildingBounds;
	private _history;
	private _hiddenBuildings;
	private _debounceHTTPErrorHandler;
	private _debounceTilesFilter;
	private _transformRequestHandler;
	isDestroyed: boolean;
	switchOutdoor: SwitchOutdoorHandler;
	switchBuilding: SwitchBuildingHandler;
	buildingSelector: BuildingSelectorHandler;
	floorSelector: FloorSelectorHandler;
	constructor(options: IMapOption);
	/**
	 * @description This function will be called once the indoor source loaded.
	 * @param callback
	 */
	renderComplete(callback: VoidFunction): void;
	destroyed(callback: VoidFunction): void;
	/**
	 * For transforming the request parameters of style resources before the map makes a request. Should be called before map.renderComplete().
	 * @param handler {maplibregl.RequestTransformFunction}
	 */
	setTransformRequest(handler: maplibregl$1.RequestTransformFunction): void;
	/**
	 * @description Get map indoor instance.
	 */
	getIndoor(): Indoor;
	/**
	 * @description Get maplibre map instance.
	 */
	getMaplibre(): maplibregl$1.Map;
	/**
	 * @description Get current selected floor info.
	 * @return {IFloor | null}
	 */
	get floor(): IFloor | null;
	/**
	 * @description Get current selected building info.
	 * @return {MapGeoJSONFeature | null}
	 */
	get building(): MapGeoJSONFeature | null;
	/**
	 * @description Get current selected venue info.
	 * @return {MapGeoJSONFeature | null}
	 */
	get venue(): MapGeoJSONFeature | null;
	/**
	 * @description Set map language.
	 * @param language {PresetLanguage} convertBrowserLangToPresetLang(Window.navigator.language).
	 */
	setLanguage(language: PresetLanguage): void;
	/**
	 * @description Get map language.
	 * @return {PresetLanguage}
	 */
	getLanguage(): PresetLanguage;
	/**
	 * @description Set outdoor map to be shown or hidden.
	 * @param shown
	 */
	setOutdoorMapShown(shown: boolean): void;
	/**
	 * @description Get features from bbox by coordinates [and ordinal].
	 * @param coordinates
	 * @param ordinal
	 */
	getIndoorFeaturesByCoordinates(coordinates: {
		lng: number;
		lat: number;
	}, ordinal?: number): {
		venue: MapGeoJSONFeature;
		building: MapGeoJSONFeature;
		level: MapGeoJSONFeature;
	};
	/**
	 * @description Query rendered features from bbox by id. One id may correspond to multiple features,
	 * coz of a feature may be multi-polygon(feature collection).
	 * @param id
	 * @param options {layerIds: string[], filter: (feature: MapGeoJSONFeature) => boolean}
	 */
	getFeaturesById(id: string, options?: {
		layerIds?: string[];
		filter?: (feature: MapGeoJSONFeature) => boolean;
	}): MapGeoJSONFeature[];
	/**
	 * @description Select indoor by locating the target floor.
	 * @param floorId
	 * @param options {dragPan: boolean} Set dragPan to be false, the map will not pan to the building center.
	 * Default is true.
	 */
	selectFloorById(floorId: string, options?: {
		dragPan?: boolean;
	}): Promise<void>;
	/**
	 * @description Select indoor by locating the target building.
	 * @param buildingId
	 * @param options {dragPan: boolean} Set dragPan to be false, the map will not pan to the building center.
	 * Default is true.
	 */
	selectBuildingById(buildingId: string, options?: {
		dragPan?: boolean;
	}): Promise<void>;
	/**
	 * @description Select indoor by locating the target venue.
	 * @param venueId 'venueId' can be string or null. Exit indoors if venueId is null.
	 * @param options {dragPan: boolean} Set dragPan to be false, the map will not pan to the building center.
	 * Default is true.
	 */
	selectVenueById(venueId: string | null, options?: {
		dragPan?: boolean;
	}): Promise<void>;
	/**
	 * @description Listen for mouse click events on the map.
	 * @param listener
	 */
	onMapClickListener(listener: (event: IMapClickEvent) => void): {
		unsubscribe: VoidFunction;
	};
	/**
	 * @description Listen for mouse click events on indoor POI
	 * @param listener
	 */
	onPoiClickListener(listener: (param: IPoiEvent) => void): {
		unsubscribe: VoidFunction;
	};
	/**
	 * @description Listen for mouse click events at a point.
	 * @param listener
	 */
	onPointClickListener(listener: (result: IPointEvent) => void): {
		unsubscribe: VoidFunction;
	};
	/**
	 * @description Listen for the indoor map status, including the changes of venue, building and floor.
	 * @param listener
	 */
	onMapChangeListener(listener: (params: {
		venue: MapGeoJSONFeature | null;
		building: MapGeoJSONFeature | null;
		floor: IFloor;
	}) => void): {
		unsubscribe: VoidFunction;
	};
	/**
	 * @description Switch the map style
	 * @param theme ThemeType | string(customized map style file name)
	 */
	switchTheme(theme: string): void;
	/**
	 * @description Set the SelectedBuildingBorder's style. If set to null, the border will be invisible.
	 * @param style {ISelectedBuildingBorderStyle | null}
	 */
	setSelectedBuildingBorderStyle(style: ISelectedBuildingBorderStyle | null): this;
	private _getStyleUrl;
	private _setIndoorFilter;
	private _setStyle;
	private _addControl;
	private _selectPoiById;
	private _resourceRequestTransform;
	private _checkMapZoom;
	private _hideIndoorLayers;
	private _showIndoorLayers;
	private _updatePermission;
	private _selectCenterBuilding;
	/**
	 * @description Query building features within the center rectangle(width: 1/2 width of map view, height: 1/2 height of map view) of map.
	 * @returns Map<buildingId, buildingFeature>
	 */
	private _getCenterBuildingsMap;
	private _destroy;
}
export declare class Marker {
	private readonly _maplibreMap;
	private readonly _layerId;
	private readonly _sourceId;
	private _imageName;
	private _imageSize;
	private _iconAnchor;
	constructor(maplibreMap: maplibregl$1.Map);
	/**
	 * @description Set custom marker image.
	 * @param icon Sprite name in map style or the URL of the image file.
	 * Image file must be in png, webp, or jpg format.
	 */
	setIcon(icon: string): Promise<void>;
	/**
	 * @description Set marker image size.
	 * @param imageScale Default is 1.
	 */
	setIconSize(imageScale: number): void;
	/**
	 * @description Set marker image anchor. Part of the icon placed closest to the anchor.
	 * @param anchor
	 */
	setIconAnchor(anchor: TAnchorPosition): void;
	/**
	 * @description Marker layer id getter.
	 */
	get layerId(): string;
	/**
	 * @description Marker source id getter.
	 */
	get sourceId(): string;
	/**
	 * @description Draw marker[s] on map.
	 * @param array {IMarkerOptions | IMarkerOptionsWithFeatureId[]} Coordinate and properties arrays of marker[s].
	 * If you need to use updateData(), the parameter must be IMarkerOptionsWithFeatureId[].
	 */
	create(array: Array<IMarkerOptions | IMarkerOptionsWithFeatureId>): void;
	/**
	 * @description Add, delete or update features of this marker layer.
	 * This approach requires unique IDs for every feature in the source!!! Including create() parameters.
	 * @param diff {remove: number[], add: IMarkerOptionsWithFeatureId[], update: IMarkerOptionsWithFeatureId[]}
	 * remove: Array of feature IDs to remove.
	 * add: Array of new features to add.
	 * update: Array of features to update, the new properties will replace the old ones.
	 */
	updateData(diff: {
		remove?: number[];
		add?: IMarkerOptionsWithFeatureId[];
		update?: IMarkerOptionsWithFeatureId[];
	}): void;
	/**
	 * @description Remove marker[s] layer and source.
	 */
	remove(): void;
	/**
	 * @description Add marker event listener.
	 * @param eventKey
	 * @param callback
	 */
	on(eventKey: keyof MapLayerEventType, callback: (marker: MapGeoJSONFeature) => void): {
		off: () => maplibregl$1.Map;
	};
	/**
	 * @description Filter marker by custom properties.
	 * @param filterExpression A expression specifying conditions on source features.
	 * Only features that match the filter are displayed. Refer:
	 * https://maplibre.org/maplibre-style-spec/expressions/
	 */
	setFilter(filterExpression: FilterSpecification): void;
	/**
	 * @description Filter marker by venueId and ordinal.
	 * Required 'venueId' and 'ordinal' in properties.
	 * Markers not matched 'venueId' and 'ordinal' would be hidden;
	 * Outdoor markers always are shown.
	 * @param venueId {string | null | undefined} null | undefined will be treated as ''.
	 * @param ordinal {string | null | undefined} null | undefined will be treated as ''.
	 */
	setFilterByVenue(venueId: string | null | undefined, ordinal: string | null | undefined): void;
	/**
	 * @description Filter marker by buildingId and ordinal.
	 * Required 'buildingId' and 'ordinal' in properties.
	 * Markers not matched 'buildingId' and 'ordinal' would be hidden;
	 * Outdoor markers always are shown.
	 * @param buildingId {string | null | undefined} null | undefined will be treated as ''.
	 * @param ordinal {string | null | undefined} null | undefined will be treated as ''.
	 */
	setFilterByBuilding(buildingId: string | null | undefined, ordinal: string | null | undefined): void;
	/**
	 * @description Set marker's icon-opacity by custom properties.
	 * @param filterExpression A expression specifying conditions on source features.
	 * Only features that match the filter are displayed. Refer:
	 * https://maplibre.org/maplibre-style-spec/expressions/
	 */
	setOpacity(filterExpression: FilterSpecification): void;
	/**
	 * @description Set marker's icon-opacity by venueId and ordinal.
	 * Required 'venueId' and 'ordinal' in properties.
	 * Opacities of markers matched 'venueId' and 'ordinal' are 1, others are 0.5.
	 * Outdoor markers' opacity always are 1.
	 * @param venueId {string | null | undefined}
	 * @param ordinal {string | null | undefined}
	 * @param inactiveOpacity {number} The opacity of marker while it's NOT in current floor, default is 0.5.
	 */
	setOpacityByVenue(venueId: string | null | undefined, ordinal: string | null | undefined, inactiveOpacity?: number): void;
	/**
	 * @description Set marker's icon-opacity by buildingId and ordinal.
	 * Required 'buildingId' and 'ordinal' in properties.
	 * Opacities of markers matched 'buildingId' and 'ordinal' are 1, others are 0.5.
	 * Outdoor markers' opacity always are 1.
	 * @param buildingId {string | null | undefined}
	 * @param ordinal {string | null | undefined}
	 * @param inactiveOpacity {number} The opacity of marker while it's NOT in current floor, default is 0.5.
	 */
	setOpacityByBuilding(buildingId: string | null | undefined, ordinal: string | null | undefined, inactiveOpacity?: number): void;
	private _createIconFeature;
	private _addIconSource;
	private _addIconLayer;
	private _handleEventListener;
}
export declare class Poi {
	private _map;
	private _layerIds;
	private _dispatch;
	private _debounceQueryFeatures;
	constructor(map: maplibregl$1.Map);
	destroy(): void;
	/**
	 * @description Listen for POI click events.
	 * @param listener
	 */
	onPoiClick(listener: (param: IPoiEvent) => void): {
		unsubscribe: VoidFunction;
	};
	private _bindEvents;
	private _queryPoiLayers;
	private _initPoiClick;
	private _getFloorDataByFloorId;
}
export interface IRouteMarkers {
	from: string | null;
	to: string | null;
	stops: Array<string | null> | null;
}
export interface IRouteStyle<T> {
	indoorLineColor?: string | ExpressionSpecification;
	outdoorLineColor?: string | ExpressionSpecification;
	dashedLineColor?: string | ExpressionSpecification;
	shuttleBusLineColor?: string | ExpressionSpecification;
	lineWidth?: number | ExpressionSpecification;
	dashedLineWidth?: number | ExpressionSpecification;
	disableDashedLine?: boolean;
	/** Optional number in range [0, 1]. Defaults to 0.5. "inactiveRouteOpacity" will be 1 if the parameter is greater than 1, and it will be 0 if the parameter is less than 0. */
	inactiveRouteOpacity?: number;
	/** Optional number in range [0, 1]. Defaults to 1. "outdoorLineOpacity" will be 1 if the parameter is greater than 1, and it will be 0 if the parameter is less than 0. */
	outdoorLineOpacity?: number;
	markers?: T;
	markerIconSize?: number | ExpressionSpecification;
	lineSymbol?: {
		/**
		 * @description Icon url or sprite name.
		 */
		image?: string | null;
		size?: number | ExpressionSpecification;
		spacing?: number | ExpressionSpecification;
	};
}
export type TRouteStyleOptions = IRouteStyle<Partial<IRouteMarkers> | Array<string | null>>;
export declare class RoutePainter {
	private readonly _maplibreMap;
	private _routeStyle;
	private _styleDiffs;
	private _filterBy;
	private _curVenue;
	private _curBuilding;
	private _curOrdinal;
	constructor(maplibreMap: maplibregl$1.Map, routeStyle?: TRouteStyleOptions);
	/**
	 * @description Set the style of the route.
	 * @param routeStyle {TRouteStyleOptions | null} When null, reset to the initial style.
	 */
	setStyle(routeStyle: TRouteStyleOptions | null): Promise<void>;
	/**
	 * @deprecated Use 'setStyle' instead.
	 * @description Set image[s] of the stop marker[s].
	 * @param icons {**Array<string | null> | {from?: string | null; to?: string | null; stops?: Array<string | null> | null;}**}
	 * Array of sprite names or URLs, or the object with specifying icon.
	 * Markers use images in order of icons array.
	 * First is as from-marker, last is as to-marker, the middles are as stop-markers.
	 * If icons array has only one element, all stop markers use this image.
	 * Image file must be in png, webp, or jpg format.
	 * Null means none image.
	 */
	setMarkerIcons(icons: Array<string | null> | {
		from?: string | null;
		to?: string | null;
		stops?: Array<string | null> | null;
	}): Promise<void>;
	/**
	 * @deprecated Use 'setStyle' instead.
	 * @description Set all icons scale.
	 * @param size number in range [0, ∞), default is 1.
	 */
	setMarkerIconSize(size: number): this;
	/**
	 * @deprecated Use 'setStyle' instead.
	 * @description Set the route color of the indoor part.
	 * @param color The color type is a color in the sRGB color space.
	 * Formats: HTML-style hex values, RGB, RGBA, HSL, and HSLA.
	 * Predefined HTML colors names, like yellow and blue, are also permitted.
	 */
	setIndoorLineColor(color: string): this;
	/**
	 * @deprecated Use 'setStyle' instead.
	 * @description Set the route color of the outdoor part.
	 * @param color The color type is a color in the sRGB color space.
	 * Formats: HTML-style hex values, RGB, RGBA, HSL, and HSLA.
	 * Predefined HTML colors names, like yellow and blue, are also permitted.
	 */
	setOutdoorLineColor(color: string): this;
	/**
	 * @deprecated Use 'setStyle' instead.
	 * @description Set color of dashed lines which connected the start and end markers.
	 * @param color The color type is a color in the sRGB color space.
	 * Formats: HTML-style hex values, RGB, RGBA, HSL, and HSLA.
	 * Predefined HTML colors names, like yellow and blue, are also permitted.
	 */
	setDashedLineColor(color: string): this;
	/**
	 * @deprecated Use 'setStyle' instead.
	 * @description Set color of shuttle bus line.
	 * @param color The color type is a color in the sRGB color space.
	 * Formats: HTML-style hex values, RGB, RGBA, HSL, and HSLA.
	 * Predefined HTML colors names, like yellow and blue, are also permitted.
	 */
	setBusLineColor(color: string): this;
	/**
	 * @description Render route on the map.
	 * @param path Route path from RouteService.search response.
	 * @param markerLocations Coordinate([lng, lat]) array of markers, order from beginning to end.
	 */
	render(path: IRoutePath, markerLocations: Array<[
		number,
		number
	]>): void;
	/**
	 * @description Remove route from the map.
	 */
	remove(): void;
	/**
	 * @description Filter paths' opacity by venue and ordinal.
	 * @param venueId {string | null | undefined}
	 * @param ordinal {string | null | undefined}
	 */
	setFilterByVenue(venueId: string | null | undefined, ordinal: string | null | undefined): void;
	/**
	 * @description Filter paths' opacity by building and ordinal.
	 * @param buildingId {string | null | undefined}
	 * @param ordinal {string | null | undefined}
	 */
	setFilterByBuilding(buildingId: string | null | undefined, ordinal: string | null | undefined): void;
	private _classifyFeatures;
	private _createLineFeature;
	private _createIconFeature;
	private _renderSolidLines;
	private _renderDashedLines;
	private _renderConnectors;
	private _renderMarkers;
	private _addCollectionSource;
	private _addLineLayer;
	private _renderLineSymbols;
	private _addIconLayer;
	private _updateStyleProperties;
	private _loadMarkerIcons;
	private _updateLayers;
	private _filterRouteOpacity;
}
/**
 * AccessControl class, for providing token and managing token lifecycle.
 * @extends EventEmitter
 * Three events are emitted:
 * - "updated": Emitted when the token is updated. Usage: accessControl.on("updated", ({ appId, token }) => {});
 * - "error": Emitted when an error occurs during token update. Usage: accessControl.on("error", (error) => {});
 * - "closed": Emitted when the access control is closed. Usage: accessControl.on("closed", () => {});
 */
export declare class AccessControl extends EventEmitter {
	private readonly _appId;
	private readonly _secret;
	isClosed: boolean;
	private _timeoutId;
	private _isInitialized;
	private readonly _initializationPromise;
	private _tokenManager;
	private readonly _from;
	constructor(appId: string, secret: string, origin?: AccessControlOrigin);
	ready(): Promise<void>;
	get appId(): string;
	/**
	 * Get the token which is kept up-to-date automatically.
	 */
	get token(): string;
	/**
	 * Destroy the access_control instance, stop updating token.
	 */
	close(): void;
	private _initToken;
	private _loopUpdateToken;
}
export declare class VenuesService {
	private _api;
	private _request;
	constructor();
	/**
	 * @description Search venues by ids.
	 * @param ids Single id string or string ids in array. The number of IDs cannot exceed 10.
	 */
	searchByIds(ids: string | string[]): TPromiseVenues;
	/**
	 * @description Search venues by center and distance.
	 * @param keywords
	 * @param center
	 * @param distance Radius from center, unit is kilometers.
	 * @param offset The maximum value is 100, default is 10.
	 * @param page Default is 1.
	 */
	searchByDistance(keywords: string, center: [
		number,
		number
	], distance: number, offset?: number, page?: number): TPromiseVenues;
	/**
	 * @description Search venues in specified bbox.
	 * @param keywords
	 * @param bbox Rectangular area, [minLon, minLat, maxLon, maxLat].
	 * @param offset The maximum value is 100, default is 10.
	 * @param page Default is 1.
	 */
	searchByBbox(keywords: string, bbox: [
		number,
		number,
		number,
		number
	], offset?: number, page?: number): TPromiseVenues;
	/**
	 * @description Search venues by global.
	 * @param keywords
	 * @param offset The maximum value is 100, default is 10.
	 * @param page Default is 1.
	 */
	searchByGlobal(keywords: string, offset?: number, page?: number): TPromiseVenues;
	search(options: IVenueSearchCustomizedOptions): TPromiseVenues;
	private _changedRes;
}
export declare class BuildingsService {
	private _api;
	private _request;
	constructor();
	/**
	 * @description Search buildings by id[s].
	 * @param ids Single id string or string ids in array. The number of IDs cannot exceed 10.
	 */
	searchByIds(ids: string | string[]): TPromiseBuildings;
	/**
	 * @description Search buildings by center and distance.
	 * @param keywords
	 * @param center
	 * @param distance Radius from center, unit is kilometers.
	 * @param offset The maximum value is 100, default is 10.
	 * @param page Default is 1.
	 */
	searchByDistance(keywords: string, center: number[], distance: number, offset?: number, page?: number): TPromiseBuildings;
	/**
	 * @description Search buildings in specified bbox.
	 * @param keywords
	 * @param bbox Rectangular area, [minLon, minLat, maxLon, maxLat].
	 * @param offset The maximum value is 100, default is 10.
	 * @param page Default is 1.
	 */
	searchByBbox(keywords: string, bbox: number[], offset?: number, page?: number): TPromiseBuildings;
	/**
	 * @description Search buildings global.
	 * @param keywords
	 * @param offset The maximum value is 100, default is 10.
	 * @param page Default is 1.
	 */
	searchByGlobal(keywords: string, offset?: number, page?: number): TPromiseBuildings;
	/**
	 * @description Search building by floor id.
	 * @param floorId
	 */
	searchByFloorId(floorId: string): TPromiseBuildings;
	search(options: IBuildingSearchCustomizedOptions): TPromiseBuildings;
	private _changedRes;
}
export declare class PoisService {
	private _api;
	private _apiV4;
	private _categoriesApi;
	private _categoriesGroupApi;
	private _request;
	constructor();
	/**
	 * @description Search POIs by id[s].
	 * @param ids Single id string or string ids in array. The number of IDs cannot exceed 100.
	 */
	searchByIds(ids: string | string[]): TPromisePois;
	/**
	 * @description Search POIs by radius distance of the center point.
	 * @param options {IPoiSearchByDistanceOptions}
	 */
	searchByDistance(options: IPoiSearchByDistanceOptions): TPromisePois;
	/**
	 * @description Search POIs in a rectangular area.
	 * @param options {IPoiSearchByBoundsOptions}
	 * 'orderBy' cannot be used with 'keywords'.
	 */
	searchByBounds(options: IPoiSearchByBoundsOptions): TPromisePois;
	/**
	 * @description Search POIs of a building.
	 * @param options {IPoiSearchByBuildingOptions}
	 * 'orderBy' cannot be used with 'keywords'.
	 */
	searchByBuilding(options: IPoiSearchByBuildingOptions): TPromisePois;
	/**
	 * @description Search POIs of a venue.
	 * @param options {IPoiSearchByVenueOptions}
	 * 'orderBy' cannot be used with 'keywords'.
	 */
	searchByVenue(options: IPoiSearchByVenueOptions): TPromisePois;
	/**
	 * @description Search POIs of a floor.
	 * @param options {IPoiSearchByFloorOptions}
	 * 'orderBy' cannot be used with 'keywords'.
	 */
	searchByFloor(options: IPoiSearchByFloorOptions): TPromisePois;
	/**
	 * @description Search poi categories by venue/building/floor/bounds.
	 * @param options
	 */
	searchCategories(options: TSearchCategoriesOptions): TPromiseCategories;
	/**
	 * @description Search surrounding POIs based on the user's location and orientation.
	 * @param options {TPoiSearchByOrientationOptions}
	 */
	searchByOrientation(options: TPoiSearchByOrientationOptions): TPromiseOrientationPois;
	/**
	 * @description Search POIs by category or excluded categories.
	 * @param options {TPoiSearchByCategoryOptions}
	 */
	searchByCategory(options: TPoiSearchByCategoryOptions): TPromisePois;
	search(options: IPoiSearchCustomizedOptions): TPromisePois;
	private _changedRes;
}
export declare class RouteService {
	private _api;
	private _request;
	constructor();
	/**
	 * @description Search the route of two or more points.
	 * @param options {IRouteSearchOptions}
	 */
	search(options: IRouteSearchOptions): TPromiseRoute;
}
export declare const OFFSET: number;
export declare const PAGE: number;
/**
 * @description Convert browser language to preset language
 * @param language {string} window.navigator.language
 */
export declare function convertBrowserLangToPresetLang(language: string): PresetLanguage | null;
export declare function getIdentifier(): Promise<string>;
export declare const VERSION: string;

export {
	Map$1 as Map,
};

export {};
